Summary:        A network ip guardian
Name:           ip-sentinel
Version:        0.12
Release:        %mkrel 19
License:        GPL-2.0-only
Group:          Networking/Other
Url:            https://www.nongnu.org/ip-sentinel/
Source0:        https://savannah.nongnu.org/download/ip-sentinel/%{name}-%{version}.tar.bz2
Source2:        ip-sentinel.service
Patch0:         ip-sentinel-0.12-lsb.patch
Patch1:         ip-sentinel-configure.patch
Patch2:         ip-sentinel-0.12-pidfile.patch
Patch3:         ip-sentinel-0.12-glibc.patch
Requires(pre):		shadow-utils
Requires(post,preun):	systemd

%description
This program tries to prevent unauthorized usage of IPs within
the local Ethernet broadcastdomain by giving an answer to
ARP-requests. After receiving such a faked reply, the requesting
party stores the told MAC in its ARP-table and will send future
packets to this MAC. Because this MAC is invalid, the host with
the invalid IP can not be reached.

Features
- non-root execution in a chroot jail
- freely customizable IPs (netmasks, negations, ranges)

%prep
%autosetup -p1

%build
autoreconf -vfi
%configure
%make_build

%install
%make_install

# Config
mkdir -p %buildroot{%_sysconfdir/sysconfig,%_unitdir,%_sysconfdir/logrotate.d}

install -pm 0644 %{SOURCE2} %{buildroot}%{_unitdir}/ip-sentinel.service

cat > %buildroot%_sysconfdir/sysconfig/%name <<EOF
IPS_USER=ip-sentinel
IPS_GROUP=ip-sentinel
# IPS_CHROOT=%_localstatedir/lib/%name
# IPS_IPFILE=ips.cfg
# IPS_LOGFILE=/var/log/ip-sentinel.out
# IPS_ERRFILE=/var/log/ip-sentinel.err
# IPS_OPTIONS=
# IPS_DEVICE=eth0

## Assign to yes if running a dietlibc-compiled version of ip-sentinel
## on a system using remote NSS for passwd-lookups (e.g. LDAP, NIS).
##
## When using a group which is not the effective group of the user,
## you will have to assign the numeric gid of this group to GROUP.
# IPS_NEEDS_NUMERIC_UID=
EOF

cat > %buildroot%_sysconfdir/logrotate.d/%name << EOF
/var/log/%name.err /var/log/%name.out {
    missingok
    notifempty
    postrotate
        /bin/kill -HUP `/bin/cat /run/%name.pid`
    endscript
}
EOF

# Data
mkdir -p %buildroot{%_localstatedir/lib/%name,%_var/log}
touch %buildroot%_var/log/%name.out
touch %buildroot%_var/log/%name.err


%pre
  %_pre_useradd %name %_localstatedir/lib/%name /bin/true

%post
  touch %_var/log/%name.out
  touch %_var/log/%name.err
  %_post_service %{name}

%postun
  %_postun_userdel %name

%preun
  %_preun_service %{name}


%files
%doc AUTHORS ChangeLog NEWS README THANKS
%license COPYING
%_sbindir/%name
%_mandir/man8/%{name}*
%dir %_localstatedir/lib/%name
%config(noreplace) %_sysconfdir/sysconfig/%name
%config(noreplace) %_sysconfdir/logrotate.d/%name
%{_unitdir}/ip-sentinel.service
%ghost %_var/log/%name.out
%ghost %_var/log/%name.err


%changelog
* Sun Jun 29 2025 umeabot <umeabot> 0.12-19.mga10
+ Revision: 2222389
- Mageia 10 Mass Rebuild

* Mon Apr 29 2024 daviddavid <daviddavid> 0.12-18.mga10
+ Revision: 2061667
- switch to systemd unit from initscripts

* Tue Mar 15 2022 umeabot <umeabot> 0.12-17.mga9
+ Revision: 1792623
- Mageia 9 Mass Rebuild

* Sat Feb 15 2020 umeabot <umeabot> 0.12-16.mga8
+ Revision: 1528466
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Aug 21 2019 daviddavid <daviddavid> 0.12-15.mga8
+ Revision: 1430785
- add patch to fix build with new glibc
- add patch fix named of pidfile

* Sun Sep 23 2018 umeabot <umeabot> 0.12-14.mga7
+ Revision: 1298312
- Mageia 7 Mass Rebuild

* Thu Feb 11 2016 umeabot <umeabot> 0.12-13.mga6
+ Revision: 954513
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.12-12.mga5
+ Revision: 745800
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.12-11.mga5
+ Revision: 680535
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.12-10.mga4
+ Revision: 523351
- Mageia 4 Mass Rebuild

* Sun Apr 07 2013 rtp <rtp> 0.12-9.mga3
+ Revision: 408931
- fix configure to look for linux-gnu* instead of linux-gnu

* Sat Jan 12 2013 umeabot <umeabot> 0.12-8.mga3
+ Revision: 354447
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat May 12 2012 colin <colin> 0.12-7.mga2
+ Revision: 235392
- Add LSB headers to initscripts (mga#5262)

* Sun Jun 26 2011 nanardon <nanardon> 0.12-6.mga2
+ Revision: 114171
- imported package ip-sentinel


* Fri Dec 10 2010 Oden Eriksson <oeriksson@mandriva.com> 0.12-6mdv2011.0
+ Revision: 619676
- the mass rebuild of 2010.0 packages

* Fri Sep 04 2009 Thierry Vignaud <tv@mandriva.org> 0.12-5mdv2010.0
+ Revision: 429520
- rebuild

* Thu Jul 24 2008 Thierry Vignaud <tv@mandriva.org> 0.12-4mdv2009.0
+ Revision: 247257
- rebuild
- fix no-buildroot-tag

  + Pixel <pixel@mandriva.com>
    - adapt to %%_localstatedir now being /var instead of /var/lib (#22312)

* Tue Dec 18 2007 Thierry Vignaud <tv@mandriva.org> 0.12-2mdv2008.1
+ Revision: 131783
- fix prereq on rpm-helper
- kill re-definition of %%buildroot on Pixel's request
- kill changelog left by repsys


* Sat Jul 15 2006 Olivier Thauvin <nanardon@mandriva.org>
+2006-07-15 18:06:19 (41315)
- rebuild
- fix url

* Sat Jul 15 2006 Olivier Thauvin <nanardon@mandriva.org>
+2006-07-15 18:04:23 (41314)
Import ip-sentinel

* Mon Apr 25 2005 Olivier Thauvin <nanardon@mandriva.org> 0.12-1mdk
- 0.12

* Sun Jan 30 2005 Sylvie Terjan <erinmargault@mandrake.org> 0.11-1mdk
- Change version to 0.11

* Tue Dec 16 2003 Olivier Thauvin <thauvin@aerov.jussieu.fr> 0.9-1mdk
- Make a specfile

